local noisily "qui"
local noisily "noisily"
estimates clear
local k=1

preserve
keep if  EXTRI!=. & EXTRI!=0 $cond
keep if NAIA>=$min_cohort & NAIA<=$max_cohort & mainland_france==1  & ($migrant ==1 | $native ==1 ) & AG>=$AGE & born_france==1  & female==$girls $cond
// Create and label Treated and post variables
global cat_controls "$controls_categorical"
global cont_controls "$controls_continuous"

// Control dummies
foreach ctrl of varlist $cont_controls  {
gen dum_ctrl_`ctrl'=(`ctrl'==.)
egen mean_`ctrl'=mean(`ctrl')
replace `ctrl'=mean_`ctrl' if `ctrl'==.
drop mean_`ctrl'
}

foreach ctrl of varlist $cat_controls {
gen dum_ctrl_`ctrl'=(`ctrl'==.)
egen mode`ctrl'=mode(`ctrl')
replace `ctrl'=mode`ctrl' if `ctrl'==.
}


// build the structure
global cat_controls2 ""
global cont_controls2 ""
* continuous vars
local t1: word count("$cont_controls")
if `t1'>1 {
forvalues k=1/`t1' {
local con: word `k' of $cont_controls
global cont_controls2 "$cont_controls2 c.`con'"
}
}


*categorical vars
local t2: word count("$cat_controls")
if `t2'>1 {
forvalues k=1/`t2' {
local con: word `k' of $cat_controls
global cat_controls2 "$cat_controls2 i.`con'"
}
}

// cohort dummies
tab NAIA, generate(dum_NAIA)
order dum_NAIA2 dum_NAIA1, last

foreach var of varlist $outcome {
* Generate post
capture drop post*
gen post=(NAIA>$not_aff_cohort) if NAIA!=.
label var post "Post"
gen post_migrant=post*$migrant 

// control mean
su `var' if $native==1 & NAIA<=$not_aff_cohort
local ctrl_mean2=round(`r(mean)',0.001)

su `var' if $migrant==1 & NAIA<=$not_aff_cohort
local ctrl_mean_mig2=round(`r(mean)',0.001)

// place right decimals
local ctrl_mean=round(`ctrl_mean2',0.001)
local ctrl_mean_mig=round(`ctrl_mean_mig2',0.001)



//////////////////////// Reg 
///////// standard DID
local k=`k'+1
`noisily' reg `var' post_migrant dum_NAIA*  $migrant post $cont_controls2 $cat_controls2  dum_ctrl_*, vce(cluster $cluster) 
estimates store modelk`k'
estadd local controls "Yes"
estadd local mean_dep_ctrl "`ctrl_mean'"
estadd local mean_dep_ctrl_mig "`ctrl_mean_mig'"


///////// Dosage regression
drop post*
gen post2=0 if NAIA<=$not_aff_cohort
replace post2=0.25 if NAIA==$not_aff_cohort+1
replace post2=0.5 if NAIA==$not_aff_cohort+2
replace post2=0.75 if NAIA==$not_aff_cohort+3
replace post2=1 if NAIA>=$not_aff_cohort+4
gen post_migrant2=post2*$migrant 

*  reg
local k=`k'+1
`noisily' reg `var' post_migrant2 dum_NAIA*  $migrant post2 $cont_controls2 $cat_controls2  dum_ctrl_*, vce(cluster $cluster) 
estimates store modelk`k'
estadd local controls "Yes"
estadd local mean_dep_ctrl "`ctrl_mean'"
estadd local mean_dep_ctrl_mig "`ctrl_mean_mig'"
}

//output
esttab modelk* using "$Tables/Table $table_tit.csv", replace keep(post_migrant*) depvars r2 ///
star(* 0.10 ** 0.05 *** 0.01) noconstant se(3) b(3) label nonotes  compress ///
s(space mean_dep_ctrl mean_dep_ctrl_mig  controls r2 N, labels(" " "Mean outcome non-Muslim $min_cohort-$not_aff_cohort" "Mean outcome Muslim $min_cohort-$not_aff_cohort" "Controls" "R2"))

//////////////////////////////// time effect
foreach var of varlist $outcome {
////////////////// time effects
su NAIA
local base_years=`r(min)'
local lowest_age=`r(min)'
local highest_age=`r(max)'
forvalues i=`lowest_age'/`highest_age' {
gen cohort_dum`i'=(NAIA==`i') if NAIA!=. & $migrant !=.
gen mig_cohort_dum`i'=(NAIA==`i' & $migrant ==1) if NAIA!=. & $migrant !=.
}
order cohort_dum$not_aff_cohort mig_cohort_dum$not_aff_cohort, last
// check non missings
`noisily' reg `var' $migrant mig_cohort_dum* cohort_dum* dum_ctrl_* $cont_controls2 $cat_controls2 , vce(cluster $cluster) 
matrix define coeff_`var'=0,0,0,0
matrix colnames coeff_`var'="Cohort" "coeff" "u_ci" "l_ci"
forvalues i=`lowest_age'/`highest_age' {
matrix coeff_`var'= coeff_`var' \ `i', _b[mig_cohort_dum`i'], _b[mig_cohort_dum`i']+1.645*_se[mig_cohort_dum`i'], _b[mig_cohort_dum`i']-1.645*_se[mig_cohort_dum`i']
if `i'==$not_aff_cohort {
matrix coeff_`var'= coeff_`var' \ $not_aff_cohort ,0,0,0
}
}
drop cohort_dum* mig_cohort_dum*
}


local graph_mi: variable label $migrant
local graph_nat: variable label $native

// collapse
* store labels
foreach v of var * {
	local l`v' : variable label `v'
      if `"`l`v''"' == "" {
		local l`v' "`v'"
}
}

collapse (mean) $outcome, by(NAIA $migrant)

* paste labels back
 foreach v of var * {
	label var `v' "`l`v''"
 }
if "$graph_tit_raw"!="" {
foreach var of varlist $outcome {
// graph
local up_line=$not_aff_cohort+4
twoway (scatter `var' NAIA if $migrant==1, sort mcolor(green) msize(small) msymbol(s)) (line `var' NAIA if $migrant==1, sort lcolor(green) lpattern(dash)) || ///
(scatter `var' NAIA if $migrant==0, sort mcolor(red) msize(small)) (line `var' NAIA if $migrant==0, sort lcolor(red))  $pcarrowi_raw /// 
, graphregion(color(white)) ///
xtitle(Birth cohorts, size(medium)) ytitle("Fracton of `subtitle'", size(medium)) legend(pos(6) ring(1) row(1) order(2 "`graph_mi'" 4 "`graph_nat'" ) symxsize(6)) ///
xlabel($min_cohort (2) $max_cohort) xline($not_aff_cohort.5, lcolor(gs3) lpattern(dash) lwidth(thin)) xline(`up_line'.5, lcolor(gs3) lpattern(dash) lwidth(thin))  ylabel(#8) 
graph export "$Graphs/Figure $graph_tit_raw.pdf", replace 
}
}
restore

//////////////////////////////////////// Graph
if "$graph_tit_coef"!="" {
foreach var of varlist $outcome {
preserve
///// single year time dummies
svmat coeff_`var',  names(col)
keep if Cohort!=. & Cohort!=0  
keep Cohort coeff u_ci l_ci
recode   u_ci l_ci (0=.)
local up_line=$not_aff_cohort+4
twoway  (scatter coeff Cohort , sort mcolor(red) msize(small) msymbol(c)) (rcap l_ci u_ci Cohort, sort msize(tiny) lcolor(navy) lpattern(solid)) ///
 $pcarrowi_coef  , graphregion(color(white)) ///
xtitle(Birth cohorts, size(medium)) ytitle("Diff. in coefficients on cohort dummies" "for Muslim and non-Muslim", size(medium)) legend(pos(6) ring(1) row(1)  order(1 "Coefficient" 2 "Confidence interval")) yline(0, lcolor(gs5) lpattern(dash) lwidth(thin)) xline($not_aff_cohort.5, lcolor(gs3) lpattern(dash) lwidth(thin)) xline(`up_line'.5, lcolor(gs3) lpattern(dash) lwidth(thin)) ///
xlabel($min_cohort (2) $max_cohort)  ysc(r(`yscalerdifgraph')) 
graph export "$Graphs/Figure $graph_tit_coef .pdf", replace
restore
}
}

