clear all
set more off, permanently

/////////////////////////////////////////////////////////////////////////////////////////
use "$DB_enquete/enquete_appended_2019.dta", clear       
////////////////// Program
capture program drop headrscarf_prog
program define headrscarf_prog, rclass
  args outcome min_cohort max_cohort girls AGE not_aff_cohort controls_categorical controls_continuous table_tit
  global outcome "`outcome'"
  global min_cohort "`min_cohort'" 
  global max_cohort "`max_cohort'" 
  global girls "`girls'" 
  global AGE "`AGE'" 
  global not_aff_cohort "`not_aff_cohort'"
  global controls_categorical "`controls_categorical'" 
  global controls_continuous "`controls_continuous'" 
  global table_tit "`table_tit'" 
  run "$do\DID_program_publication.do"
end 

keep if RGA==1
global graph_tit_raw ""
global graph_tit_coef ""

// Fix MSTC
destring MSTC, replace
replace  MSTC=. if  MSTC==9

* unemployed mother  - to match with TeO
destring CSPM NAIA AG DIP, replace
replace CSPM=. if CSPM==0
gen homemother2=1 if inlist(CSPM,81,82)
replace homemother2=0 if CSPM!=. & homemother2==.
tostring CSPM, replace
label var homemother2 "Housewife"

/////// Education
global migrant parents_maghreb_me
global native  parents_french
drop if NAIA<1965 | NAIA>2000 | AG<18 | DIP==. 
keep if RGA==1

/////// B3 panel A
preserve
local age=21
keep if $migrant==1 | $native==1
keep if (NAIA>=1971 & NAIA<=1974) | (NAIA>=1987 & NAIA<=1990)
gen post=(NAIA>=1979)
// See means in ouctome
foreach var of varlist bac_bacpro {
local i=1
matrix `var'_pattern_female_`i'=0,0,0,0,0,0,0,0,0,0
local rname=`"~"'
reg `var' $migrant##post  if female==`i' & AG>=`age' & mainland_france==1 & born_france==1 & DIP!=. & EXTRI!=0, r 
local diff=_b[1.$migrant#1.post]
local pval_diff=2 * (1-normal(abs(_b[1.$migrant#1.post ]/_se[1.$migrant#1.post])))
local se_dif=_se[1.$migrant#1.post]


reg `var' i.$migrant  if post==0 & female==`i' & AG>=`age' & mainland_france==1 & born_france==1 & DIP!=. & EXTRI!=0, r 
matrix `var'_pattern_female_`i'=`var'_pattern_female_`i'\_b[_cons]+_b[1.$migrant], _se[1.$migrant], _b[_cons],_se[_cons],_b[1.$migrant],_se[1.$migrant ],2 * (1-normal(abs(_b[1.$migrant ]/_se[1.$migrant ]))),.,.,.
local rname `" `rname' "1971-1974"  "'
reg `var' i.$migrant  if post==1 & female==`i' & AG>=`age' & mainland_france==1 & born_france==1 & DIP!=. & EXTRI!=0, r 
matrix `var'_pattern_female_`i'=`var'_pattern_female_`i'\_b[_cons]+_b[1.$migrant], _se[1.$migrant], _b[_cons],_se[_cons],_b[1.$migrant],_se[1.$migrant ], 2 * (1-normal(abs(_b[1.$migrant ]/_se[1.$migrant ]))), `diff',`se_dif',`pval_diff'

local rname `" `rname' "1987-1990" "'
matrix colnames `var'_pattern_female_`i'="Muslim  (a)" "SE" "Non-Muslim  (b)" "SE" "(a)-(b)" "SE" "(a-b) p-value" "diff across cohorts" "SE" "P-value of diff across cohorts"
matrix rownames `var'_pattern_female_`i'=`rname'
putexcel set "$Tables/Table B3 panel A.xls", sheet("Sheet1") replace
putexcel A1=matrix(`var'_pattern_female_`i'), names   nformat(#.000)
}
restore


/////// B3 panel B
preserve
local age=21
keep if $migrant==1 | $native==1
keep if (NAIA>=1971 & NAIA<=1974) | (NAIA>=1987 & NAIA<=1990)
gen post=(NAIA>=1979)
// See means in ouctome
foreach var of varlist bac_bacpro {
local i=0
matrix `var'_pattern_female_`i'=0,0,0,0,0,0,0,0,0,0
local rname=`"~"'
reg `var' $migrant##post if female==`i' & AG>=`age' & mainland_france==1 & born_france==1 & DIP!=. & EXTRI!=0, r 
local diff=_b[1.$migrant#1.post]
local pval_diff=2 * (1-normal(abs(_b[1.$migrant#1.post ]/_se[1.$migrant#1.post])))
local se_dif=_se[1.$migrant#1.post]

reg `var' i.$migrant if post==0 & female==`i' & AG>=`age' & mainland_france==1 & born_france==1 & DIP!=. & EXTRI!=0, r 
matrix `var'_pattern_female_`i'=`var'_pattern_female_`i'\_b[_cons]+_b[1.$migrant], _se[1.$migrant], _b[_cons],_se[_cons],_b[1.$migrant],_se[1.$migrant ],2 * (1-normal(abs(_b[1.$migrant ]/_se[1.$migrant ]))),.,.,.
local rname `" `rname' "1971-1974"  "'
reg `var' i.$migrant if post==1 & female==`i' & AG>=`age' & mainland_france==1 & born_france==1 & DIP!=. & EXTRI!=0, r 
matrix `var'_pattern_female_`i'=`var'_pattern_female_`i'\_b[_cons]+_b[1.$migrant], _se[1.$migrant], _b[_cons],_se[_cons],_b[1.$migrant],_se[1.$migrant ], 2 * (1-normal(abs(_b[1.$migrant ]/_se[1.$migrant ]))), `diff',`se_dif',`pval_diff'
local rname `" `rname' "1987-1990" "'
matrix colnames `var'_pattern_female_`i'="Muslim  (a)" "SE" "Non-Muslim  (b)" "SE" "(a)-(b)" "SE" "(a-b) p-value" "diff across cohorts" "SE" "P-value of diff across cohorts"
matrix rownames `var'_pattern_female_`i'=`rname'
putexcel set "$Tables/Table B3 panel B.xls", sheet("Sheet1") replace
putexcel A1=matrix(`var'_pattern_female_`i'), names   nformat(#.000)
}
restore



///////////// Summary statisctics 
gen parisdep=(DNAI_raw=="75") if DNAI_raw!=""
label var parisdep "Born in Paris department"
gen rofw_mother_se=(inlist(NATMER,3,4,5,9,10)) if NATMER!=.
label var rofw_father  "Non-Muslim foreign father"
label var rofw_mother_se "Non-Muslim foreign mother"

/////////// B1 cols 1 and 2 
preserve
local age=21
local cov_se "bac_bacpro parisdep mag_father af_father me_father rofw_father french_mother musmother  rofw_mother_se skilled_father" 
keep if $migrant==1 | $native==1
// See means in ouctome
local i=1 
matrix se_female_`i'=0,0,0
local rname=`"~"'

su ANNE if NAIA>=1971  & NAIA<=1990 & $migrant==1 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0
local n_mus=`r(N)'
su ANNE if NAIA>=1971  & NAIA<=1990 & $native==1 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0
local n_nat=`r(N)'

foreach var of local cov_se {
reg `var' $migrant  if NAIA>=1971  & NAIA<=1990 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0, r 
matrix se_female_`i'=se_female_`i'\ _b[_cons]+_b[$migrant], _b[_cons], 2 * (1-normal(abs(_b[$migrant ]/_se[$migrant ])))
local lbl: variable label `var'
local rname `" `rname' "`lbl'""'
}

matrix se_female_`i'=se_female_`i'\ `n_mus',`n_nat',.
local rname `" `rname' "Observations" "'

matrix colnames se_female_`i'="Muslim" "Non-Muslim" "P-value"
matrix rownames se_female_`i'=`rname'
putexcel set "$Tables/Table B1 cols 1 and 2 .xls", sheet("Sheet1") replace
putexcel A1=matrix(se_female_`i'), names
restore


/////////// B1 cols 3 and 4 
preserve
local age=21
local cov_se "bac_bacpro  parisdep mag_father af_father me_father rofw_father french_mother musmother  rofw_mother_se skilled_father" 
keep if $migrant==1 | $native==1
// See means in ouctome
local i=0
matrix se_female_`i'=0,0,0
local rname=`"~"'

su ANNE if NAIA>=1971  & NAIA<=1990 & $migrant==1 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0
local n_mus=`r(N)'
su ANNE if NAIA>=1971  & NAIA<=1990 & $native==1 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0
local n_nat=`r(N)'

foreach var of local cov_se {
reg `var' $migrant if NAIA>=1971  & NAIA<=1990 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0, r 
matrix se_female_`i'=se_female_`i'\ _b[_cons]+_b[$migrant], _b[_cons], 2 * (1-normal(abs(_b[$migrant ]/_se[$migrant ])))
local lbl: variable label `var'
local rname `" `rname' "`lbl'""'
}

matrix se_female_`i'=se_female_`i'\ `n_mus',`n_nat',.
local rname `" `rname' "Observations" "'
matrix colnames se_female_`i'="Muslim" "Non-Muslim" "P-value"
matrix rownames se_female_`i'=`rname'
putexcel set "$Tables/Table B1 cols 3 and 4 .xls", sheet("Sheet1") replace
putexcel A1=matrix(se_female_`i'), names
restore



/////////// B2 cols 1 and 2 
preserve
local age=21
keep if $migrant==1 | $native==1
local i=1
matrix se_female_`i'=0,0,0
local rname=`"~"'

su ANNE if NAIA>=1983  & NAIA<=1998 & $migrant==1 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0
local n_mus=`r(N)'
su ANNE if NAIA>=1983  & NAIA<=1998 & $native==1 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0
local n_nat=`r(N)'

foreach var of local cov_se {
reg `var' $migrant if NAIA>=1983  & NAIA<=1998 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0, r 
matrix se_female_`i'=se_female_`i'\ _b[_cons]+_b[$migrant], _b[_cons], 2 * (1-normal(abs(_b[$migrant ]/_se[$migrant ])))
local lbl: variable label `var'
local rname `" `rname' "`lbl'""'
}

matrix se_female_`i'=se_female_`i'\ `n_mus',`n_nat',.
local rname `" `rname' "Observations" "'
matrix colnames se_female_`i'="Muslim" "Non-Muslim" "P-value"
matrix rownames se_female_`i'=`rname'
putexcel set "$Tables/Table B2 cols 1 and 2.xls", sheet("Sheet1") replace
putexcel A1=matrix(se_female_`i'), names
restore


/////////// B2 cols 3 and 4 
preserve
local age=21
keep if $migrant==1 | $native==1
local i=0
matrix se_female_`i'=0,0,0
local rname=`"~"'
su ANNE if NAIA>=1983  & NAIA<=1998 & $migrant==1 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0
local n_mus=`r(N)'
su ANNE if NAIA>=1983  & NAIA<=1998 & $native==1 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0
local n_nat=`r(N)'
foreach var of local cov_se {
reg `var' $migrant if NAIA>=1983  & NAIA<=1998 & female==`i' & mainland_france==1 & born_france==1 & AG>=`age' & DIP!=. & EXTRI!=0, r 
matrix se_female_`i'=se_female_`i'\ _b[_cons]+_b[$migrant], _b[_cons], 2 * (1-normal(abs(_b[$migrant ]/_se[$migrant ])))
local lbl: variable label `var'
local rname `" `rname' "`lbl'""'
}

matrix se_female_`i'=se_female_`i'\ `n_mus',`n_nat',.
local rname `" `rname' "Observations" "'
matrix colnames se_female_`i'="Muslim" "Non-Muslim" "P-value"
matrix rownames se_female_`i'=`rname'
putexcel set "$Tables/Table B2 cols 3 and 4.xls", sheet("Sheet1") replace
putexcel A1=matrix(se_female_`i'), names
restore


//////////////// table B4 panels A & B
global controles "auxctrl2 NATPER" 
global cond ""
global cluster nat_cohort_dep 

headrscarf_prog "survey skilled_father parisdep" "1971" "1990" "1" "21" "1979"  ///
"$controles" "auxctrl" "B4 A"

headrscarf_prog "survey skilled_father parisdep" "1971" "1990" "0" "21" "1979"  ///
"$controles" "auxctrl"   "B4 B"

///////////////////////// Education
global controles "auxctrl2 survey DNAI skilled_father NATPER"  
global raw_bac_bacpro "0.5 0.8"
global upperbound_raw=0.8
global lowerbound_raw=0.5
global pcarrowi_raw (pcarrowi 0.75 1984.7 0.75 1983.7 (3) "Middle school age in 1994", mc(gs7) lc(gs7) mlabc(gs7)) 

global diff_bac_bacpro "-0.15 0.2"
global upperbound_coef= 0.2
global lowerbound_coef= -0.15
global pcarrowi_coef (pcarrowi 0.2 1984.7 0.2 1983.7 (3) "Middle school age in 1994", mc(gs7) lc(gs7) mlabc(gs7)) 
global graph_tit_raw "1A"
global graph_tit_coef "1B"
headrscarf_prog "bac_bacpro" "1971" "1990" "1" "21" "1979" "$controles" "auxctrl" "1A col 1 and 2"

global graph_tit_raw ""
global graph_tit_coef "C1"

headrscarf_prog "bac_bacpro" "1971" "1990" "0" "21" "1979"  "$controles" "auxctrl" "1A col 3 and 4"
global graph_tit_coef ""

//////////// Table 1 panel B
headrscarf_prog "YE" "1971" "1990" "1" "24" "1979" "$controles" "auxctrl" "1 panel B cols 1 & 2"
headrscarf_prog "YE" "1971" "1990" "0" "24" "1979" "$controles" "auxctrl" "1 panel B cols 3 & 4"



//////////// low ses ---- This is an extra revision, so do not delete
preserve
drop if (inrange(CSPP,81,82) | skilled_father==.)  & $native==1
drop if (skilled_father==1 | skilled_father==.) & $native==1
headrscarf_prog "bac_bacpro" "1971" "1990" "1" "21" "1979" "$controles" "auxctrl" "B7 panel A col 1 and 2"
headrscarf_prog "bac_bacpro" "1971" "1990" "0" "21" "1979"  "$controles" "auxctrl" "B7 panel A col 3 and 4"
headrscarf_prog "YE" "1971" "1990" "1" "24" "1979" "$controles" "auxctrl" "B7 panel B col 1 and 2"
headrscarf_prog "YE" "1971" "1990" "0" "24" "1979" "$controles" "auxctrl" "B7 panel B col 3 and 4"
restore


// tab NIVET if  EXTRI!=. & EXTRI!=0 & bac_bacpro!=. & NAIA>=1971 & NAIA<=1990 & mainland_france==1  & (parents_maghreb_me ==1 | $native ==1 ) & AG>=21 & born_france==1 & female==1
// tab NIVET if  EXTRI!=. & EXTRI!=0 & bac_bacpro!=. & NAIA>=1971 & NAIA<=1990 & mainland_france==1  & (parents_maghreb_me ==1 | $native ==1 ) & AG>=21 & born_france==1 & female==0
//
// tab NIVET DIP if  EXTRI!=. & EXTRI!=0 & bac_bacpro!=. & NAIA>=1971 & NAIA<=1990 & mainland_france==1  & (parents_maghreb_me ==1 | $native ==1 ) & AG>=21 & born_france==1 & female==1
// tab NIVET DIP if  EXTRI!=. & EXTRI!=0 & bac_bacpro!=. & NAIA>=1971 & NAIA<=1990 & mainland_france==1  & (parents_maghreb_me ==1 | $native ==1 ) & AG>=21 & born_france==1 & female==0

 gen beforhischool=(inrange(NIVET,40,51)  & bac_bacpro==0) if NIVET!=.
 gen beforemischool=(NIVET>51 & bac_bacpro==0) if NIVET!=.
 gen bacgen_tech_plus=(DIP<43) if DIP!=.
 gen bacpro=(DIP==43) if DIP!=.
 gen term_bacpro=(NIVET==43) if NIVET!=.

/*
preserve
headrscarf_prog "midschool_drop bacgen_tech_plus bacpro term_bacpro" "1971" "1990" "1" "21" "1979" "$controles" "auxctrl"  "exB6 col 1 & 2"
headrscarf_prog "midschool_drop bacgen_tech_plus bacpro term_bacpro" "1971" "1990" "0" "21" "1979" "$controles" "auxctrl"  "exB6 col 3 & 4"
restore
*/

//////////// some LFS ---- This is an extra revision, so do not delete
preserve
drop if ANNEE>2012
headrscarf_prog "bac_bacpro" "1971" "1990" "1" "21" "1979" "$controles" "auxctrl" "F3 Panel A 1 & 2"
headrscarf_prog "bac_bacpro" "1971" "1990" "0" "21" "1979"  "$controles" "auxctrl" "F3 Panel A 3 & 4"
headrscarf_prog "YE" "1971" "1990" "1" "24" "1979" "$controles" "auxctrl" "F3 Panel B 1 & 2"
headrscarf_prog "YE" "1971" "1990" "0" "24" "1979" "$controles" "auxctrl" "F3 Panel B 3 & 4"
restore
/////////////////// Table B6
capture program drop headrscarf_prog_tripleDID
program define headrscarf_prog_tripleDID, rclass
  args outcome min_cohort max_cohort girls AGE not_aff_cohort controls_categorical controls_continuous table_tit
  global outcome "`outcome'" 
  global min_cohort "`min_cohort'" 
  global max_cohort "`max_cohort'" 
  global girls "`girls'" 
  global AGE "`AGE'" 
  global not_aff_cohort "`not_aff_cohort'" 
  global controls_categorical "`controls_categorical'" 
  global controls_continuous "`controls_continuous'" 
  global table_tit "`table_tit'" 
  run "$do\Triple_DID_progra_publication.do" 
end 

global tripleterm "female"
headrscarf_prog_tripleDID "bac_bacpro" "1971" "1990" "1" "21" "1979" "$controles" "auxctrl"  "Table B6 cols 1 & 2"
headrscarf_prog_tripleDID "YE" "1971" "1990" "1" "24" "1979" "$controles" "auxctrl" "Table B6 cols 3 & 4"

//////////// Triple dif lowskilled low income ---- This is an extra revision, so do not delete
preserve
drop if (inrange(CSPP,81,82) | skilled_father==.)  & $native==1
drop if (skilled_father==1 | skilled_father==.)  & $native==1

headrscarf_prog_tripleDID "bac_bacpro" "1971" "1990" "1" "21" "1979" "$controles" "auxctrl"  "Table B8 cols 1 & 2"
headrscarf_prog_tripleDID "YE" "1971" "1990" "1" "24" "1979" "$controles" "auxctrl" "Table B8 cols 3 & 4"
restore



//////////////////// B4 panel C
local replace replace
foreach outm of varlist survey skilled_father parisdep female {
preserve
capture drop post*
gen post=(NAIA>1979) if NAIA!=.
noisily reg `outm' c.post##parents_maghreb_me i.NAIA i.NATPER  if  EXTRI!=. & EXTRI!=0 & bac_bacpro!=. & NAIA>=1971 & NAIA<=1990 & mainland_france==1  & (parents_maghreb_me ==1 | $native ==1 ) & AG>=21 & born_france==1, vce(cluster nat_cohort_dep) 
outreg2 using "$Tables/Table B4 panel C.xls", `replace'  keep(1.parents_maghreb_me#c.post) label 
local replace append

capture drop post*
gen post2=0 if NAIA<=1979
replace post2=0.25 if NAIA==1979+1
replace post2=0.5 if NAIA==1979+2
replace post2=0.75 if NAIA==1979+3
replace post2=1 if NAIA>=1979+4

noisily reg `outm' c.post2##parents_maghreb_me i.NAIA i.NATPER  if  EXTRI!=. & EXTRI!=0 & bac_bacpro!=. & NAIA>=1971 & NAIA<=1990 & mainland_france==1  & (parents_maghreb_me ==1 | $native ==1 ) & AG>=21 & born_france==1, vce(cluster nat_cohort_dep) 
outreg2 using "$Tables/Table B4 panel C.xls", `replace' keep(1.parents_maghreb_me#c.post2) label 
capture drop post* dum_sf
restore
}


/////////////////////////////////////////////Long term outcome
////////////////// Program
capture program drop headrscarf_prog_longterm
program define headrscarf_prog_longterm, rclass
  args outcome min_cohort max_cohort girls AGE not_aff_cohort controls_categorical controls_continuous  table_tit
  global outcome "`outcome'" 
  global min_cohort "`min_cohort'" 
  global max_cohort "`max_cohort'" 
  global girls "`girls'" 
  global AGE "`AGE'" 
  global not_aff_cohort "`not_aff_cohort'" 
  global controls_categorical "`controls_categorical'" 
  global controls_continuous "`controls_continuous'" 
  global table_tit "`table_tit'" 
  run "$do\DID_program_longterm_publication.do" 
end 

////////////////// Table 4
preserve 
global controles "auxctrl2 survey DNAI skilled_father NATPER"  
keep if (AG>=(2005-1975) & AG<=(2019-1986))
headrscarf_prog_longterm "active employed logwage pubsector" "1975" "1986" "1" "29" "1979"  "$controles" "auxctrl"  "Table 4 panel A"
headrscarf_prog_longterm "active employed logwage pubsector" "1975" "1986" "0" "29" "1979"  "$controles" "auxctrl"  "Table 4 panel B"
restore


////////////////// Table 3
foreach var of varlist frenchpartner muslim_partner rofwpartner {
gen `var'_3=`var'_2
recode `var'_3 (. 1=0) if NOICON==.
replace `var'_3=0 if `var'_3==.
}

gen married_frpartner=(married2==1 & frenchpartner_3==1)
replace married_frpartner=1 if married2==1 & rofwpartner==1
gen married_muspartner=(married2==1 & muslim_partner_3==1)
gen married_rofwpartner=(married2==1 & rofwpartner==1)
gen married_mispartner=(married2==1 & married_rofwpartner==0 & married_muspartner==0 & married_frpartner==0)
replace married_frpartner=1 if married2==1 & married_rofwpartner==0 & married_muspartner==0 & married_frpartner==0

recode married_frpartner married_muspartner (1/2=0) if married2==0
recode married_frpartner married_muspartner (0/2=.) if married2==.


preserve 
global controles "auxctrl2 survey DNAI skilled_father NATPER"  
keep if (AG>=(2005-1975) & AG<=(2019-1986))
headrscarf_prog_longterm "YE married2 married_frpartner married_muspartner nunmberofchildren" "1975" "1986" "1" "29" "1979"   "$controles" "auxctrl"  "Table 3 panel A"
headrscarf_prog_longterm "YE married2 married_frpartner married_muspartner nunmberofchildren" "1975" "1986" "0" "29" "1979"   "$controles" "auxctrl"  "Table 3 panel B"
restore


///////////////////////////////////////////// Table D1
global migrant rofw_father
global graph_tit_coef "D1"
global graph_tit_raw ""
headrscarf_prog "bac_bacpro" "1971" "1990" "1" "21" "1979"  ///
"$controles" "auxctrl" "D1"

//////////////////////////////////////Estimation 2004 law 
global migrant parents_maghreb_me
global native  parents_french 

////////////////////////////////////// Table E1
global graph_tit_raw "E1 A"
global graph_tit_coef "E1 B"

headrscarf_prog "bac_bacpro" "1983" "1998" "1" "21" "1989" "$controles" "auxctrl" ///
 "E1 col 1 & 2"


global graph_tit_raw ""
global graph_tit_coef "E2"
headrscarf_prog "bac_bacpro" "1983" "1998" "0" "21" "1989" "$controles" "auxctrl" ///
 "E1 col 3 & 4"
global graph_tit_coef ""


///////////////////////////  Heteronegeous treatment effect 
capture program drop headrscarf_prog_hetero_new
program define headrscarf_prog_hetero_new, rclass
  args outcome interaction min_cohort max_cohort girls AGE not_aff_cohort controls_categorical controls_continuous table_tit 
  global outcome "`outcome'" 
  global interaction "`interaction'" 
  global min_cohort "`min_cohort'" 
  global max_cohort "`max_cohort'" 
  global girls "`girls'" 
  global AGE "`AGE'" 
  global not_aff_cohort "`not_aff_cohort'"
  global controls_categorical "`controls_categorical'" 
  global controls_continuous "`controls_continuous'" 
  global table_tit "`table_tit'"
  run "$do\DID_program new het_publication.do"
end 

/////// Table 2 panel A
gen Maghreb_father_me=1 if NATPER==6|NATPER==8
replace Maghreb_father_me=2 if NATPER==7
replace Maghreb_father_me=0  if NATPER==1
gen all=1 if Maghreb_father_me==1 | Maghreb_father_me==2

global migrant all
global native  parents_french 
global cond " & NATPER!=."
global controles "auxctrl2 survey DNAI skilled_father NATPER"  
global interaction2 ""
global coeff "1.Maghreb_father_me#c.post 2.Maghreb_father_me#c.post"

headrscarf_prog_hetero_new "YE" "Maghreb_father_me" "1971" "1990" "1" "24" "1979"  ///
"$controles" "auxctrl"  "Table 2 panel A"

/////// Table 2 panel C
capture drop all
generate musmfather_bornmus=0 if NATPER==1
replace musmfather_bornmus=1 if inlist(NATPER,6,7,8) & inlist(PAIPERC,1,2,3,4,5,9,10)  
replace musmfather_bornmus=2 if inlist(NATPER,6,7,8) & inlist(PAIPERC,6,7,8)  
gen frenchfather_bornfr=0 if inlist(NATPER,1) & inlist(PAIPERC,1)  
replace frenchfather_bornfr=1 if inlist(NATPER,1) & inlist(PAIPERC,6,7,8)  
replace frenchfather_bornfr=2 if inlist(NATPER,6,7,8) & inlist(PAIPERC,1)  
replace frenchfather_bornfr=3 if inlist(NATPER,6,7,8) & inlist(PAIPERC,6,7,8)  
recode musmfather_bornmus frenchfather_bornfr (0 1 2 =.) if NATPER==. | PAIPERC==.
gen all=1 if inlist(frenchfather_bornfr,1,2,3,4) |musmfather_bornmus==1|musmfather_bornmus==2

destring CSPM MSTC, replace
replace CSPM=. if CSPM==0
* Accomodate this dataset
gen skilled_father_stored_aux=skilled_father
gen homemother2_aux=homemother2
gen NATPER_0=NATPER
gen NATMER_0=NATMER
gen NATPER_1=NATPER
gen NATMER_1=NATMER
recode NATPER_1 NATMER_1 NATPER_0 NATMER_0 (3 4 5 =2)
foreach ctrl of varlist NATPER_1 NATMER_1 NATPER_0 NATMER_0 skilled_father_stored_aux homemother2_aux  {
gen dum_c_`ctrl'=(`ctrl'==.)
egen mode`ctrl'=mode(`ctrl')
replace `ctrl'=mode`ctrl' if `ctrl'==.
}

* predict veil
local female=1
preserve
use "$DB_enquete/for_predict_TeO.dta", clear
* accomodate data
rename housewives2 homemother2
rename (skilled_father homemother2) (skilled_father_stored_aux  homemother2_aux)
gen NATPER_0=NAT_7 
gen NATMER_0=NATPARTNER_7
gen NATPER_1=NATPARTNER_7
gen NATMER_1=NAT_7
foreach ctrl of varlist NATPER_`female' NATMER_`female' skilled_father_stored_aux  homemother2_aux {
gen dum_c_`ctrl'=(`ctrl'==.)
egen mode`ctrl'=mode(`ctrl')
replace `ctrl'=mode`ctrl' if `ctrl'==.
}
* regression
keep if NAIA>=1945 & NAIA<=1960  & female==`female'
logit veil  i.NATPER_`female' i.NATMER_`female'  i.skilled_father_stored_aux  i.homemother2_aux dum_c_*, r
restore
predict veil_hat, pr
replace veil_hat=veil_hat
drop NATPER_1 NATMER_1 NATPER_0 NATMER_0 skilled_father_stored_aux  homemother2_aux dum_c_* mode*

* Estimate veil 
global migrant parents_maghreb_me
global native  parents_french
global controles "auxctrl2 survey DNAI skilled_father NATPER homemother2 NATMER"  
global interaction2 "c.veil_hat##c.post"
global coeff "c.veil_hat#c.post"
headrscarf_prog_hetero_new "YE" "auxctrl3" "1971" "1990" "1" "24" "1979"  "$controles" "auxctrl" "Table 2 panel C"


/////// Table 2 panel B
* unemployed mother using all info
gen homemother4=. if CSPM==. & MSTC==.
replace homemother4=0 if ((CSPM<80) | inlist(CSPM,84,85,86)) | MSTC!=.
replace homemother4=1 if  inlist(CSPM,81,82) & MSTC==.
gen Maghreb_father_me_homem=1 if (NATPER==6|NATPER==7|NATPER==8) & homemother4==0
replace Maghreb_father_me_homem=2 if (NATPER==6|NATPER==7|NATPER==8) & homemother4==1
replace Maghreb_father_me_homem=0 if NATPER==1
gen frenchfather=(NATPER==1) if inlist(NATPER,1,6,7,8)
replace frenchfather=. if homemother4==.

drop all
gen all=1 if  inrange(Maghreb_father_me_homem,1,2) 
global cond ""
global controles "auxctrl2 survey DNAI skilled_father NATPER homemother4"  
global interaction2 "i.frenchfather##c.post i.NATPER##i.homemother4"
global coeff "1.Maghreb_father_me_homem#c.post 2.Maghreb_father_me_homem#c.post"
global cond "& homemother4!=."

 headrscarf_prog_hetero_new "YE" "Maghreb_father_me_homem" "1971" "1990" "1" "24" "1979"  ///
"$controles" "auxctrl" "Table 2 panel B"


