preserve
keep if EXTRI!=. & EXTRI!=0 $cond 
keep if NAIA>=$min_cohort & NAIA<=$max_cohort & mainland_france==1  & ($migrant ==1 | $native ==1 ) & AG>=$AGE & born_france==1  

// Create and label Treated and post variables
global cat_controls "$controls_categorical"
global cont_controls "$controls_continuous"

// Control dummies
foreach ctrl of varlist $cont_controls  {
gen dum_ctrl_`ctrl'=(`ctrl'==.)
egen mean_`ctrl'=mean(`ctrl')
replace `ctrl'=mean_`ctrl' if `ctrl'==.
drop mean_`ctrl'
}

foreach ctrl of varlist $cat_controls {
gen dum_ctrl_`ctrl'=(`ctrl'==.)
egen mode`ctrl'=mode(`ctrl')
replace `ctrl'=mode`ctrl' if `ctrl'==.
}



// build the structure
* continuous vars
local t1: word count("$cont_controls")
if `t1'>1 {
forvalues k=1/`t1' {
local con: word `k' of $cont_controls
global cont_controls2 "$cont_controls2 c.`con'"
}
}


*categorical vars
local t2: word count("$cat_controls")
if `t2'>1 {
forvalues k=1/`t2' {
local con: word `k' of $cat_controls
global cat_controls2 "$cat_controls2 i.`con'"
}
}

tab NAIA, generate(dum_NAIA)
order dum_NAIA2 dum_NAIA1, last

foreach var of varlist $outcome {
* Generate post
capture drop post*
gen post=(NAIA>$not_aff_cohort) if NAIA!=.
label var post "Post"
gen post_migrant=post*$migrant 

//////////////////////// Reg 
/////////  DID
gen post_fem=post*$tripleterm
gen post_mig=post*$migrant
gen fem_mig=$tripleterm*$migrant
gen post_fem_mig=post*$tripleterm*$migrant


* standard DID
local k=`k'+1
noisily reg `var' post_fem_mig fem_mig post_mig post_fem $migrant c.post $tripleterm dum_NAIA*  $migrant post $cont_controls2 $cat_controls2  dum_ctrl_*   i.NATPER##i.NAIA i.NATPER##$tripleterm i.NAIA##$tripleterm, vce(cluster $cluster) 
estimates store modelk`k'
estadd local controls "Yes"


///////// Dosage regression
drop post* fem_mig*
gen post2=0 if NAIA<=$not_aff_cohort
replace post2=0.25 if NAIA==$not_aff_cohort+1
replace post2=0.5 if NAIA==$not_aff_cohort+2
replace post2=0.75 if NAIA==$not_aff_cohort+3
replace post2=1 if NAIA>=$not_aff_cohort+4
label var post2 "Post"

gen post_fem2=post2*$tripleterm
gen post_mig2=post2*$migrant
gen fem_mig2=$tripleterm*$migrant
gen post_fem_mig2=post2*$tripleterm*$migrant


* standard DID,  control 
local k=`k'+1
noisily reg `var' post_fem_mig2 fem_mig2 post_mig2 post_fem2 $migrant $tripleterm c.post2 dum_NAIA*  $migrant $cont_controls2 $cat_controls2  dum_ctrl_* i.NATPER##i.NAIA i.NATPER##$tripleterm i.NAIA##$tripleterm, vce(cluster $cluster) 
estimates store modelk`k'
estadd local controls "Yes"
}
restore

esttab modelk* using "$Tables/$table_tit.csv", replace keep(post_fem_mig*) depvars r2 ///
star(* 0.10 ** 0.05 *** 0.01) noconstant se(3) b(3) label nonotes  compress ///
s(space controls r2 N, labels(" " "Controls" "R2"))


