clear all

////////////////////////// Clean the data for with the right variables
* NATPER  is not present in 2004
forvalues i=5/19 { 
* fix the 0 in the path
if `i'<10 {
local i="0`i'"
}
// store temporally relevamt vars per year
forvalues j=1/4 { 
use "$Path_enquete\Enquête Emploi en continu (version FPR) - 20`i'\Stata\INDIV`i'`j'.dta", clear
// Uniform names
foreach var of varlist _all {
rename `var' `=upper("`var'")'
}
// fix var names so I have the same names across years
capture rename EXTRI1 EXTRID
capture rename NATMERC NATMER 
capture rename NATPERC NATPER 	
capture rename COHAB COURED 	
capture rename OTRAVM MSTC
capture rename EM1 ENFRED

di in red `i'
forvalues k=1/9 {
capture rename NOIENF0`k' NOIENF`k'
}

if `i'>=13 {
destring MSTC, replace 
recode MSTC (2=1)
recode MSTC (3=2)
recode MSTC (4=3)
tostring MSTC, replace 
}

// keep vars
keep IDENT NOI ANNE TRIM NAIA NAIM EXTRI SEXE NATMER NATPER DIP DDIPL DEP  ///
NOIPER NOIMER LNAIS  CSPM CSPP REG  MATRI  RGA DNAI AG   ACTEU6  SALRED  PAIMERC PAIPERC  ///
MSTC ACTEU  COURED NOICON  NOIENF1 NOIENF2 NOIENF3 NOIENF4 NOIENF5 NOIENF6 NOIENF7 NOIENF8 NOIENF9 NOIENF10 NOIENF11 NOIENF12 NOIENF13 NOIENF14 ENFRED ///
NIVET STATUT
qui tostring  _all, replace
destring ANNEE, replace
tempfile temp_20`i'_`j'    /* create a temporary file */
save "`temp_20`i'_`j''"      /* save memory into the temporary file */
}
}

////////////////////////// Append data
drop _all
set obs 1
generate a = 999999

// append
forvalues i=5/19 { 
* fix the 0 in the path
if `i'<10 {
local i="0`i'"
}
forvalues j=1/4 { 
append using "`temp_20`i'_`j''",  generate(source_20`i'_`j')
}
}
// drop auxiliar
keep if a==.
drop a
drop source_20* 

////////////////////////// Label variables
label var IDENT "Household id" 
label var NOI   "Person id"
label var ANNE  "Survey year"
label var TRIM  "Survey quarter"
label var AG  "Age, 31/12"
label var NAIA  "Year of birth"
label var NAIM  "Month of birth"
label var DNAI  "Region of birth"
label var EXTRI "Quarter weight"
label var SEXE "Sex"
label var DDIPL "Highest degree obtained"
label var DIP "Highest degree obtained, more classification"
label var LNAIS "Birth in France or abroad"
label var NATMER "Mother's Nationality (grouped) of birth"
label var NATPER "Father's Nationality (grouped) of birth"
label var CSPM "Mother's Professional category "
label var CSPP "Father's Professional category "
label var REG "Residential area"
label var RGA "Cluster query rank"
label var ACTEU6 "Activity status within the meaning of ILO"
label var PAIMERC "Mother's country of birth"
label var PAIPERC "Father's country of birth"
label var COURED "Living with the couple"
label var NOICON "Id partner"

forvalues k=1/14 {
label var NOIENF`k' "children number`k'"
}


////////////////////////// Label values
order IDENT NOI ANNEE TRIM NAIM NAIA  SEXE REG EXTRI  DDIPL  LNAIS  NATPER NATMER  CSPP, first 
destring NAIM, replace force
replace NAIM=. if NAIM==99

// some destring
destring DDIPL DIP ANNE, replace force
destring PAIMERC PAIPERC NATMER NATPER, replace
recode NATMER NATPER PAIMERC PAIPERC (99=.)


// Mainland France - survey
destring REG, replace
gen mainland_france=(REG>=5) if REG!=.
recode REG (94=93)
label var mainland_france "Mainland France"


// Bac or more
gen bac_bacpro=(DIP<=43) if DIP!=.
tab DIP bac_bacpro, mis
label var bac_bacpro "Baccalauréat or more"


* French born in france 
destring LNAIS, replace
gen born_france=(LNAIS==1) if LNAIS!=.
label var born_france "Born in France"


// Gender
destring SEXE MATRI, replace
gen female=(SEXE==2) if SEXE!=.
label var female "Girl"

//Marriage
gen married2=(MATRI!=1) if MATRI!=.
label var married2 "Ever married"

// Skilled father
tab CSPP, mis
tostring CSPP, replace force
gen skilled_father=.
replace skilled_father=1 if CSPP=="21" |CSPP=="22" |CSPP=="23" |CSPP=="31" |CSPP=="33" |CSPP=="34" |CSPP=="35" |CSPP=="37"|CSPP=="38" |CSPP=="42" |CSPP=="43" |CSPP=="44" |CSPP=="45" |CSPP=="46" |CSPP=="47" |CSPP=="48" |CSPP=="72" |CSPP=="74" |CSPP=="75"
replace skilled_father=0 if skilled_father!=1 & CSPP=="10" |CSPP=="11" |CSPP=="12" |CSPP=="13" |CSPP=="52" |CSPP=="53" |CSPP=="54" |CSPP=="55" |CSPP=="56" |CSPP=="62" |CSPP=="63" |CSPP=="64" |CSPP=="65" |CSPP=="67"|CSPP=="68" |CSPP=="69" |CSPP=="71" |CSPP=="77" |CSPP=="78" |CSPP=="81" |CSPP=="82" |CSPP=="84"|CSPP=="85" |CSPP=="86"
replace skilled_father=. if CSPP=="0"
label var skilled_father "Father is a skilled worker"
destring CSPP, replace

// Employed
destring ACTEU6, replace
gen employed=(ACTEU6==1) if ACTEU6!=.
label var employed "Employed"
tab ACTEU6 employed, mis

// Active
tab ACTEU6, mis
gen active=(ACTEU6==1|ACTEU6==3|ACTEU6==4) if ACTEU6!=.
label var active "Active in labor mkt."
tab ACTEU6 active, mis

// wage 
destring SALRED, replace
gen wage=SALRED
label var wage "Wage"
su wage, d
replace wage=r(p99) if wage>r(p99) & wage!=.
replace wage=r(p1) if wage<r(p1) & wage!=.
su wage, d

/// number of children
foreach var of varlist NOIENF*{
replace `var' = subinstr(`var', ".", "",.) 
}
egen nunmberofchildren=rownonmiss(NOIENF*), strok
label var nunmberofchildren "Number of children"


// Survey group and DNAI
gen DNAI_raw=DNAI
drop DNAI
egen DNAI=group(DNAI_raw), missing
capture egen survey=group(ANNE TRIM), missing
label var survey "Survey date"


gen auxctrl=1
gen auxctrl2=auxctrl
gen auxctrl3=auxctrl2
label var NAIA "Cohort"


/// gen mother vars
gen french_mother=(NATMER==1) if NATMER!=.
label var french_mother "French mother"

gen musmother=(NATMER==6|NATMER==7|NATMER==8) if NATMER!=.
label var musmother "Muslim mother" 

// father vars
gen mag_father=(NATPER==6) if NATPER!=.
label var mag_father "Maghreb father" 

gen af_father=(NATPER==7) if NATPER!=.
label var af_father "African father" 

gen me_father=(NATPER==8) if NATPER!=.
label var me_father "Middle-east father" 

gen french_father=(NATPER==1) if NATPER!=.
label var french_father "French father" 

// cluster vars
egen nat_cohort_dep=group(NATPER DNAI), missing

* groups
gen parents_maghreb_me=(NATPER==6|NATPER==7|NATPER==8) if NATPER!=. 
label var parents_maghreb_me "Muslim background"
gen parents_french=(NATPER==1) if NATPER!=.
label var parents_french "non-Muslim background"
gen rofw_father=(inlist(NATPER,3,4,5,9,10)) if NATPER!=. 
label var rofw_father "a migrant non-Muslim background"

// years of educ
gen YE=0 if DDIPL==7 
replace YE=1 if DDIPL==6
replace YE=2 if DDIPL==5
replace YE=3 if DDIPL==4
replace YE=4 if DDIPL==3
replace YE=5 if DDIPL==1
label var YE "Years of education"
tab DDIPL YE, mis

// logwage
gen logwage=ln(wage)
replace logwage=. if employed!=1

// Muslim partner
destring  NOICON NOI RGA, replace
gen muslim_partner=.
label var muslim_partner "Muslim partner"
sort IDENT ANNEE TRIM
su NOICON
forvalues i=1/`r(max)' {
gen noiconaux_`i'=parents_maghreb_me if NOI==`i'
by IDENT ANNEE TRIM: egen noicon_`i'=max(noiconaux_`i')
replace muslim_partner=1 if noicon_`i'==1 & NOICON==`i'
replace muslim_partner=0 if noicon_`i'==0 & NOICON==`i'
drop noicon_`i' noiconaux_`i'
}
* fix values
replace muslim_partner=. if NOICON==.

// French partner
gen frenchpartner=.
label var frenchpartner "non-Muslim partner"
sort IDENT ANNEE TRIM
su NOICON
forvalues i=1/`r(max)' {
gen noiconaux_`i'=parents_french if NOI==`i'
by IDENT ANNEE TRIM: egen noicon_`i'=max(noiconaux_`i')
replace frenchpartner=1 if noicon_`i'==1 & NOICON==`i'
replace frenchpartner=0 if noicon_`i'==0 & NOICON==`i'
drop noicon_`i' noiconaux_`i'
}
* fix values
replace frenchpartner=. if NOICON==.

// rofw partner
gen rofwpartner=.
sort IDENT ANNEE TRIM
su NOICON
forvalues i=1/`r(max)' {
gen noiconaux_`i'=rofw_father if NOI==`i'
by IDENT ANNEE TRIM: egen noicon_`i'=max(noiconaux_`i')
replace rofwpartner=1 if noicon_`i'==1 & NOICON==`i'
replace rofwpartner=0 if noicon_`i'==0 & NOICON==`i'
drop noicon_`i' noiconaux_`i'
}
replace rofwpartner=. if NOICON==.

//// retrieve values from later waves if it was missing in the first one
gen frenchpartner_2=frenchpartner
gen muslim_partner_2=muslim_partner
gen rofwpartner_2=rofwpartner
forvalues i=1/6 {
gen NOICON_`i'=NOICON if RGA==`i'
bys IDENT NOI: egen NOICON_`i'_aux=max(NOICON_`i')
foreach var of varlist  frenchpartner muslim_partner rofwpartner  { 
gen `var'_`i'`i'=`var' if RGA==`i'
bys IDENT NOI ANNEE: egen `var'_`i'`i'_aux=max(`var'_`i'`i')
replace `var'_2=`var'_`i'`i'_aux if RGA==1 &  NOICON_`i'_aux==NOICON & `var'_2==.
drop `var'_`i'`i' `var'_`i'`i'_aux
}
drop NOICON_`i' NOICON_`i'_aux
}


// Before high school dropout
br NIVET
destring NIVET, replace force
destring NIVET, replace force
gen midschool_drop=(NIVET>51) if NIVET!=.
label var midschool_drop "less than high school"

// working in the public sector
destring STATUT, replace force
replace STATUT=. if STATUT==99
gen pubsector=(inlist(STATUT,43,44,45)) if STATUT!=.
label var pubsector "Public employee"
 
*save dataset
save "$DB_enquete/enquete_appended_2019.dta", replace      
